IncreaseKLDOnEpoch - LatentLego

Skip to content

# IncreaseKLDOnEpoch

### `latent.callbacks.IncreaseKLDOnEpoch`

Increase Kullback-Leibler Divergence loss of VAEs during training.

#### `__init__(self, factor=1.5, max_val=1.0, **kwargs)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`factor` | `float` | Positive float. Factor by which the KLD will be increased each epoch. | `1.5`
`max_val` | `float` | Positive float. Maximum value of KLD. | `1.0`
`**kwargs` | `` | Other parameters passed to `keras.callbacks.Callback`. | `{}`